@@ -7,8 +7,8 @@
 # CREATED    : in original form: Apr 1997
 #              completely redone: Oct 1997
 # MODIFIED   : 
-# VERSION    : $Id: Structure.pm,v 2.11 1999/10/28 23:13:16 greg Exp $
-# COPYRIGHT  : Copyright (c) 1997-98 by Gregory P. Ward.  All rights
+# VERSION    : $Id: Structure.pm,v 2.14 2000/03/23 02:08:40 greg Exp $
+# COPYRIGHT  : Copyright (c) 1997-2000 by Gregory P. Ward.  All rights
 #              reserved.
 # 
 #              This file is part of the Text::BibTeX library.  This
@@ -23,7 +23,7 @@ require 5.004;                              # for 'isa' and 'can'
 use strict;
 use Carp;
 
-import Text::BibTeX ('check_class');
+use Text::BibTeX ('check_class');
 
 =head1 NAME
 
@@ -870,7 +870,7 @@ use vars qw(@ISA);
 use Carp;
 
 @ISA = ('Text::BibTeX::Entry');
-BEGIN { import Text::BibTeX qw(:metatypes display_list) }
+use Text::BibTeX qw(:metatypes display_list);
 
 =head1 METHODS 2: BASE STRUCTURED ENTRY CLASS
 
@@ -1143,7 +1143,7 @@ sub full_check
 {
    my ($self, $warn, $coerce) = @_;
 
-   return 1 unless $self->metatype == BTE_REGULAR;
+   return 1 unless $self->metatype == &BTE_REGULAR;
    return unless $self->check_type ($warn);
    return $self->check_required_fields ($warn, $coerce) &&
           $self->check_field_constraints ($warn, $coerce);
@@ -1196,6 +1196,6 @@ Greg Ward <gward@python.net>
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-98 by Gregory P. Ward.  All rights reserved.  This file
+Copyright (c) 1997-2000 by Gregory P. Ward.  All rights reserved.  This file
 is part of the Text::BibTeX library.  This library is free software; you
 may redistribute it and/or modify it under the same terms as Perl itself.
